@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import logging
 import os
-import pickle
 import secrets
 import subprocess
 import sys
@@ -11,6 +10,7 @@ from multiprocessing import resource_tracker, shared_memory
 from multiprocessing.connection import Listener
 from typing import IO, TYPE_CHECKING, cast
 
+import daft.pickle
 from daft.errors import UDFException
 from daft.expressions import Expression, ExpressionsProjection
 from daft.recordbatch import MicroPartition
@@ -63,6 +63,17 @@ class UdfHandle:
         # Copy the current process environment
         env = dict(os.environ)
 
+        # Copy the logging configuration of the current process
+        root = logging.getLogger()
+        env["LOG_LEVEL"] = str(root.level)
+        for h in root.handlers:
+            if hasattr(h, "formatter") and h.formatter is not None:
+                if h.formatter._fmt:
+                    env["LOG_FORMAT"] = h.formatter._fmt
+                if h.formatter.datefmt:
+                    env["LOG_DATE_FORMAT"] = h.formatter.datefmt
+                break
+
         # Python auto-buffers stdout by default, so disable
         env["PYTHONUNBUFFERED"] = "1"
 
@@ -88,7 +99,7 @@ class UdfHandle:
         expr_projection = ExpressionsProjection(
             [Expression._from_pyexpr(expr) for expr in passthrough_exprs] + [Expression._from_pyexpr(project_expr)]
         )
-        expr_projection_bytes = pickle.dumps(expr_projection)
+        expr_projection_bytes = daft.pickle.dumps(expr_projection)
         self.handle_conn.send((_ENTER, expr_projection_bytes))
         response = self.handle_conn.recv()
         if response != _READY:
@@ -116,12 +127,18 @@ class UdfHandle:
         response = self.handle_conn.recv()
         stdout = self.trace_output()
         if response[0] == _UDF_ERROR:
-            base_exc: Exception = pickle.loads(response[3])
-            if sys.version_info >= (3, 11):
-                base_exc.add_note("\n".join(response[2].format()))
+            try:
+                base_exc: Exception | None = daft.pickle.loads(response[3])
+            except TypeError:
+                base_exc = None
+
+            if base_exc is None and sys.version_info >= (3, 11):
+                raise UDFException(response[1], response[2])
+            if base_exc and sys.version_info >= (3, 11):
+                base_exc.add_note("\n".join(response[2].format()).rstrip())  # type: ignore[attr-defined]
             raise UDFException(response[1]) from base_exc
         elif response[0] == _ERROR:
-            raise RuntimeError("Actor Pool UDF unexpectedly failed with traceback:\n" + "\n".join(response[1].format()))
+            raise RuntimeError("UDF unexpectedly failed with traceback:\n" + "\n".join(response[1].format()))
         elif response[0] == _SUCCESS:
             out_name, out_size = response[1], response[2]
             output_bytes = self.transport.read_and_release(out_name, out_size)
