@@ -4,6 +4,7 @@ from .expressions import (
     Expression,
     ExpressionsProjection,
     col,
+    element,
     list_,
     lit,
     interval,
@@ -19,6 +20,7 @@ __all__ = [
     "ExpressionsProjection",
     "coalesce",
     "col",
+    "element",
     "interval",
     "list_",
     "lit",
