@@ -1,10 +1,10 @@
-use proc_macro2::{Ident, TokenStream};
-use proc_macro_crate::{crate_name, FoundCrate};
+use proc_macro_crate::{FoundCrate, crate_name};
 use proc_macro_error::{abort, abort_call_site, emit_error};
+use proc_macro2::{Ident, TokenStream};
 use quote::{format_ident, quote};
 use syn::{
-    parse_macro_input, spanned::Spanned, Data, DeriveInput, Fields, FieldsNamed, GenericArgument,
-    GenericParam, Generics, LitStr, PathArguments, Type, TypePath,
+    Data, DeriveInput, Fields, FieldsNamed, GenericArgument, GenericParam, Generics, LitStr,
+    PathArguments, Type, TypePath, parse_macro_input, spanned::Spanned,
 };
 
 enum ArgCardinality {
@@ -19,7 +19,7 @@ enum ArgCardinality {
 enum ArgType {
     Generic,
     #[allow(unused)]
-    Concrete(Type),
+    Concrete(Box<Type>),
 }
 
 struct ParsedAttribute {
@@ -350,27 +350,26 @@ fn get_arg_types(
             {
                 ArgType::Generic
             } else {
-                ArgType::Concrete(ty.clone())
+                ArgType::Concrete(Box::new(ty.clone()))
             }
         })
         .collect()
 }
 
 fn get_option_type_inner(ty: &Type) -> &Type {
-    if let Type::Path(TypePath { qself: None, path }) = ty {
-        if path.segments.len() == 1 {
-            let segment = path.segments.first().unwrap();
+    if let Type::Path(TypePath { qself: None, path }) = ty
+        && path.segments.len() == 1
+    {
+        let segment = path.segments.first().unwrap();
 
-            if segment.ident == "Option" {
-                if let PathArguments::AngleBracketed(args) = &segment.arguments {
-                    if args.args.len() == 1 {
-                        let arg = args.args.first().unwrap();
+        if segment.ident == "Option"
+            && let PathArguments::AngleBracketed(args) = &segment.arguments
+            && args.args.len() == 1
+        {
+            let arg = args.args.first().unwrap();
 
-                        if let GenericArgument::Type(inner_type) = arg {
-                            return inner_type;
-                        }
-                    }
-                }
+            if let GenericArgument::Type(inner_type) = arg {
+                return inner_type;
             }
         }
     }
@@ -382,20 +381,19 @@ fn get_option_type_inner(ty: &Type) -> &Type {
 }
 
 fn get_vec_type_inner(ty: &Type) -> &Type {
-    if let Type::Path(TypePath { qself: None, path }) = ty {
-        if path.segments.len() == 1 {
-            let segment = path.segments.first().unwrap();
+    if let Type::Path(TypePath { qself: None, path }) = ty
+        && path.segments.len() == 1
+    {
+        let segment = path.segments.first().unwrap();
 
-            if segment.ident == "Vec" {
-                if let PathArguments::AngleBracketed(args) = &segment.arguments {
-                    if args.args.len() == 1 {
-                        let arg = args.args.first().unwrap();
+        if segment.ident == "Vec"
+            && let PathArguments::AngleBracketed(args) = &segment.arguments
+            && args.args.len() == 1
+        {
+            let arg = args.args.first().unwrap();
 
-                        if let GenericArgument::Type(inner_type) = arg {
-                            return inner_type;
-                        }
-                    }
-                }
+            if let GenericArgument::Type(inner_type) = arg {
+                return inner_type;
             }
         }
     }
