@@ -248,19 +248,11 @@ impl ConnectSession {
     }
 
     fn http_config_helper(&self, http_conf: &mut HTTPConfig) -> DaftResult<()> {
-        if let Some(value) = self
-            .config_values
-            .get("daft.io.http.user_agent")
-            .map(|s| s.to_string())
-        {
+        if let Some(value) = self.config_values.get("daft.io.http.user_agent").cloned() {
             http_conf.user_agent = value;
         }
 
-        if let Some(value) = self
-            .config_values
-            .get("daft.io.http.bearer_token")
-            .map(|s| s.to_string())
-        {
+        if let Some(value) = self.config_values.get("daft.io.http.bearer_token").cloned() {
             http_conf.bearer_token = Some(value.into());
         }
 
