@@ -2,6 +2,6 @@ mod task;
 mod worker;
 mod worker_manager;
 
-pub(super) use task::{RayPartitionRef, RaySwordfishTask, RayTaskResult};
+pub(crate) use task::{RayPartitionRef, RaySwordfishTask, RayTaskResult};
 pub(crate) use worker::RaySwordfishWorker;
 pub(crate) use worker_manager::RayWorkerManager;
