@@ -1,6 +1,3 @@
-#![feature(let_chains)]
-#![feature(if_let_guard)]
-
 mod arithmetic;
 pub mod expr;
 pub mod functions;
@@ -16,12 +13,12 @@ mod visitor;
 mod treenode;
 pub use common_treenode;
 pub use expr::{
-    binary_op, bound_col, count_actor_pool_udfs, deduplicate_expr_names, estimated_selectivity,
-    exprs_to_schema, has_agg, is_actor_pool_udf, is_partition_compatible, is_udf, left_col, lit,
-    null_lit, resolved_col, right_col, unresolved_col,
-    window::{window_to_agg_exprs, WindowBoundary, WindowFrame, WindowSpec},
     AggExpr, ApproxPercentileParams, Column, Expr, ExprRef, Operator, PlanRef, ResolvedColumn,
-    SketchType, Subquery, SubqueryPlan, UnresolvedColumn, WindowExpr,
+    SketchType, Subquery, SubqueryPlan, UnresolvedColumn, WindowExpr, binary_op, bound_col,
+    count_actor_pool_udfs, deduplicate_expr_names, estimated_selectivity, exprs_to_schema, has_agg,
+    is_actor_pool_udf, is_partition_compatible, is_udf, left_col, lit, null_lit, resolved_col,
+    right_col, unresolved_col,
+    window::{WindowBoundary, WindowFrame, WindowSpec, window_to_agg_exprs},
 };
 #[cfg(feature = "python")]
 use pyo3::prelude::*;
