@@ -6,9 +6,6 @@ use serde::{Deserialize, Serialize};
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub struct MonotonicallyIncreasingId;
 
-#[derive(FunctionArgs)]
-struct Args {}
-
 #[typetag::serde]
 impl ScalarUDF for MonotonicallyIncreasingId {
     fn name(&self) -> &'static str {
