@@ -4,15 +4,16 @@ use common_image::{BBox, CowImage};
 use daft_core::{
     array::{
         ops::image::{
-            fixed_image_array_from_img_buffers, image_array_from_img_buffers, AsImageObj,
+            AsImageObj, fixed_image_array_from_img_buffers, image_array_from_img_buffers,
         },
         prelude::*,
     },
     datatypes::prelude::*,
     prelude::ImageArray,
 };
+use daft_schema::image_property::ImageProperty;
 
-use crate::{iters::ImageBufferIter, CountingWriter};
+use crate::{CountingWriter, iters::ImageBufferIter};
 
 pub trait ImageOps {
     fn encode(&self, image_format: ImageFormat) -> DaftResult<BinaryArray>;
@@ -31,6 +32,7 @@ pub trait ImageOps {
     fn to_mode(&self, mode: ImageMode) -> DaftResult<Self>
     where
         Self: Sized;
+    fn attribute(&self, attr: ImageProperty) -> DaftResult<DataArray<UInt32Type>>;
 }
 
 impl ImageOps for ImageArray {
@@ -75,6 +77,27 @@ impl ImageOps for ImageArray {
             .collect();
         image_array_from_img_buffers(self.name(), &buffers, Some(mode))
     }
+
+    fn attribute(&self, attr: ImageProperty) -> DaftResult<DataArray<UInt32Type>> {
+        match attr {
+            ImageProperty::Height => Ok(self.heights().clone().rename(self.name())),
+            ImageProperty::Width => Ok(self.widths().clone().rename(self.name())),
+            ImageProperty::Channel => Ok(self
+                .channels()
+                .clone()
+                .cast(&DataType::UInt32)?
+                .u32()?
+                .clone()
+                .rename(self.name())),
+            ImageProperty::Mode => Ok(self
+                .modes()
+                .clone()
+                .cast(&DataType::UInt32)?
+                .u32()?
+                .clone()
+                .rename(self.name())),
+        }
+    }
 }
 
 impl ImageOps for FixedShapeImageArray {
@@ -135,6 +158,32 @@ impl ImageOps for FixedShapeImageArray {
         };
         fixed_image_array_from_img_buffers(self.name(), &buffers, &mode, *height, *width)
     }
+
+    fn attribute(&self, attr: ImageProperty) -> DaftResult<DataArray<UInt32Type>> {
+        let (height, width) = match self.data_type() {
+            DataType::FixedShapeImage(_, h, w) => (h, w),
+            _ => unreachable!("Should be FixedShapeImage type"),
+        };
+
+        match attr {
+            ImageProperty::Height => Ok(UInt32Array::from((
+                self.name(),
+                vec![*height; self.len()].as_slice(),
+            ))),
+            ImageProperty::Width => Ok(UInt32Array::from((
+                self.name(),
+                vec![*width; self.len()].as_slice(),
+            ))),
+            ImageProperty::Channel => Ok(UInt32Array::from((
+                self.name(),
+                vec![self.image_mode().num_channels() as u32; self.len()].as_slice(),
+            ))),
+            ImageProperty::Mode => Ok(UInt32Array::from((
+                self.name(),
+                vec![(*self.image_mode() as u8) as u32; self.len()].as_slice(),
+            ))),
+        }
+    }
 }
 
 fn encode_images<Arr: AsImageObj>(
@@ -217,7 +266,7 @@ fn encode_images<Arr: AsImageObj>(
     )
 }
 
-fn resize_images<Arr: AsImageObj>(images: &Arr, w: u32, h: u32) -> Vec<Option<CowImage>> {
+fn resize_images<Arr: AsImageObj>(images: &Arr, w: u32, h: u32) -> Vec<Option<CowImage<'_>>> {
     ImageBufferIter::new(images)
         .map(|img| img.map(|img| img.resize(w, h)))
         .collect::<Vec<_>>()
