@@ -3,12 +3,12 @@ use std::{any::Any, sync::Arc, time::Duration};
 use async_trait::async_trait;
 use common_io_config::GCSConfig;
 use common_runtime::get_io_pool_num_threads;
-use futures::{stream::BoxStream, TryStreamExt};
+use futures::{TryStreamExt, stream::BoxStream};
 use google_cloud_storage::{
-    client::{google_cloud_auth::credentials::CredentialsFile, Client, ClientConfig},
+    client::{Client, ClientConfig, google_cloud_auth::credentials::CredentialsFile},
     http::{
-        objects::{get::GetObjectRequest, list::ListObjectsRequest},
         Error as GError,
+        objects::{get::GetObjectRequest, list::ListObjectsRequest},
     },
 };
 use google_cloud_token::{TokenSource, TokenSourceProvider};
@@ -17,12 +17,12 @@ use snafu::{IntoError, ResultExt, Snafu};
 use tokio::sync::Semaphore;
 
 use crate::{
+    FileFormat, GetResult, InvalidRangeRequestSnafu,
     object_io::{FileMetadata, FileType, LSResult, ObjectSource},
     range::GetRange,
     retry::{ExponentialBackoff, RetryError},
     stats::IOStatsRef,
     stream_utils::io_stats_on_bytestream,
-    FileFormat, GetResult, InvalidRangeRequestSnafu,
 };
 
 const GCS_DELIMITER: &str = "/";
@@ -488,7 +488,9 @@ impl GCSSource {
             match attempted {
                 Ok(attempt) => attempt,
                 Err(err) => {
-                    log::warn!("Google Cloud Storage Credentials not provided or found when making client. Reverting to Anonymous mode.\nDetails\n{err}");
+                    log::warn!(
+                        "Google Cloud Storage Credentials not provided or found when making client. Reverting to Anonymous mode.\nDetails\n{err}"
+                    );
                     ClientConfig::default().anonymous()
                 }
             }
@@ -499,7 +501,7 @@ impl GCSSource {
         }
         client_config.http = Some({
             use reqwest_middleware::ClientBuilder;
-            use reqwest_retry::{policies::ExponentialBackoff, RetryTransientMiddleware};
+            use reqwest_retry::{RetryTransientMiddleware, policies::ExponentialBackoff};
             use retry_policies::Jitter;
             let retry_policy = ExponentialBackoff::builder()
                 .base(2)
@@ -546,6 +548,10 @@ impl GCSSource {
 
 #[async_trait]
 impl ObjectSource for GCSSource {
+    async fn supports_range(&self, _: &str) -> super::Result<bool> {
+        Ok(true)
+    }
+
     async fn get(
         &self,
         uri: &str,
