@@ -2,10 +2,10 @@ use std::{borrow::Cow, collections::HashMap, fmt::Display, sync::Arc};
 
 use common_daft_config::DaftExecutionConfig;
 use common_display::{
+    DisplayLevel,
     ascii::fmt_tree_gitstyle,
     mermaid::{MermaidDisplayVisitor, SubgraphOptions},
     tree::TreeDisplay,
-    DisplayLevel,
 };
 use common_error::{DaftError, DaftResult};
 use common_file_formats::FileFormat;
@@ -18,10 +18,10 @@ use daft_local_plan::{
     WindowOrderByOnly, WindowPartitionAndDynamicFrame, WindowPartitionAndOrderBy,
     WindowPartitionOnly,
 };
-use daft_logical_plan::{stats::StatsState, JoinType};
+use daft_logical_plan::{JoinType, stats::StatsState};
 use daft_micropartition::{
-    partitioning::{MicroPartitionSet, PartitionSetCache},
     MicroPartition, MicroPartitionRef,
+    partitioning::{MicroPartitionSet, PartitionSetCache},
 };
 use daft_scan::ScanTaskRef;
 use daft_writers::make_physical_writer_factory;
@@ -29,6 +29,7 @@ use indexmap::IndexSet;
 use snafu::ResultExt;
 
 use crate::{
+    ExecutionRuntimeContext, PipelineCreationSnafu,
     channel::Receiver,
     intermediate_ops::{
         cross_join::CrossJoinOperator,
@@ -66,7 +67,6 @@ use crate::{
         limit::LimitSink, monotonically_increasing_id::MonotonicallyIncreasingIdSink,
         outer_hash_join_probe::OuterHashJoinProbeSink,
     },
-    ExecutionRuntimeContext, PipelineCreationSnafu,
 };
 
 pub type NodeName = Cow<'static, str>;
@@ -727,6 +727,7 @@ fn physical_plan_to_pipeline(
             pivot_column,
             value_column,
             aggregation,
+            pre_agg,
             names,
             stats_state,
             ..
@@ -738,6 +739,7 @@ fn physical_plan_to_pipeline(
                 value_column.clone(),
                 aggregation.clone(),
                 names.clone(),
+                *pre_agg,
             );
             BlockingSinkNode::new(Arc::new(pivot_sink), child_node, stats_state.clone(), ctx)
                 .boxed()
