@@ -19,5 +19,5 @@ pub use plan::{
     WindowPartitionAndDynamicFrame, WindowPartitionAndOrderBy, WindowPartitionOnly,
 };
 #[cfg(feature = "python")]
-pub use python::{register_modules, PyLocalPhysicalPlan};
+pub use python::{PyLocalPhysicalPlan, register_modules};
 pub use translate::translate;
