@@ -4,19 +4,20 @@ use common_error::DaftResult;
 use common_treenode::{Transformed, TreeNode, TreeNodeRecursion};
 use daft_core::prelude::*;
 use daft_dsl::{
-    functions::{scalar::ScalarFn, FunctionArgs},
+    AggExpr, ApproxPercentileParams, Column, Expr, ExprRef,
+    functions::{FunctionArgs, scalar::ScalarFn},
     optimization,
     python_udf::{PyScalarFn, RowWisePyFn},
-    resolved_col, AggExpr, ApproxPercentileParams, Column, Expr, ExprRef,
+    resolved_col,
 };
 use indexmap::{IndexMap, IndexSet};
 use itertools::Itertools;
 use serde::{Deserialize, Serialize};
 
 use crate::{
+    LogicalPlan,
     logical_plan::{self},
     stats::StatsState,
-    LogicalPlan,
 };
 
 #[derive(Clone, Debug, PartialEq, Eq, Hash, Serialize, Deserialize)]
@@ -638,12 +639,12 @@ fn replace_column_with_semantic_id_aggexpr(
 mod tests {
     use common_error::DaftResult;
     use daft_core::prelude::*;
-    use daft_dsl::{binary_op, lit, resolved_col, Operator};
+    use daft_dsl::{Operator, binary_op, lit, resolved_col};
 
     use crate::{
+        LogicalPlan,
         ops::Project,
         test::{dummy_scan_node, dummy_scan_operator},
-        LogicalPlan,
     };
 
     /// Test that nested common subexpressions are correctly split
