@@ -4,16 +4,16 @@ use common_error::DaftResult;
 use common_treenode::{DynTreeNode, Transformed, TreeNode};
 use daft_core::prelude::*;
 use daft_dsl::{
-    optimization::replace_columns_with_expressions, resolved_col, Column, Expr, ExprRef,
-    ResolvedColumn,
+    Column, Expr, ExprRef, ResolvedColumn, optimization::replace_columns_with_expressions,
+    resolved_col,
 };
 use indexmap::IndexSet;
 
 use super::OptimizerRule;
 use crate::{
+    LogicalPlan, LogicalPlanRef,
     ops::{Aggregate, Join, Pivot, Project, Source, UDFProject},
     source_info::SourceInfo,
-    LogicalPlan, LogicalPlanRef,
 };
 
 #[derive(Default, Debug)]
@@ -668,6 +668,7 @@ mod tests {
     use daft_dsl::{lit, resolved_col, unresolved_col};
 
     use crate::{
+        LogicalPlan,
         ops::{Project, Unpivot},
         optimization::{
             optimizer::{RuleBatch, RuleExecutionStrategy},
@@ -675,7 +676,6 @@ mod tests {
             test::assert_optimized_plan_with_rules_eq,
         },
         test::{dummy_scan_node, dummy_scan_node_with_pushdowns, dummy_scan_operator},
-        LogicalPlan,
     };
 
     /// Helper that creates an optimizer with the PushDownProjection rule registered, optimizes
