@@ -1,15 +1,15 @@
 use common_error::DaftResult;
 use common_treenode::{ConcreteTreeNode, Transformed, TreeNode};
-use daft_dsl::{is_partition_compatible, ExprRef};
+use daft_dsl::{ExprRef, is_partition_compatible};
 use daft_logical_plan::partitioning::{ClusteringSpec, HashClusteringConfig};
 
 use crate::{
+    PhysicalPlan, PhysicalPlanRef,
     ops::{
         ActorPoolProject, Aggregate, Explode, HashJoin, Project, ShuffleExchange,
         ShuffleExchangeStrategy, Unpivot,
     },
     optimization::{plan_context::PlanContext, rules::PhysicalOptimizerRule},
-    PhysicalPlan, PhysicalPlanRef,
 };
 
 pub struct ReorderPartitionKeys {}
@@ -188,15 +188,15 @@ mod tests {
 
     use common_error::DaftResult;
     use daft_core::prelude::*;
-    use daft_dsl::{resolved_col, ExprRef};
+    use daft_dsl::{ExprRef, resolved_col};
     use daft_logical_plan::partitioning::{ClusteringSpec, UnknownClusteringConfig};
 
     use crate::{
+        PhysicalPlan, PhysicalPlanRef,
         ops::{EmptyScan, HashJoin, ShuffleExchangeFactory},
         optimization::rules::{
-            reorder_partition_keys::ReorderPartitionKeys, PhysicalOptimizerRule,
+            PhysicalOptimizerRule, reorder_partition_keys::ReorderPartitionKeys,
         },
-        PhysicalPlan, PhysicalPlanRef,
     };
 
     fn create_dummy_plan(schema: SchemaRef, num_partitions: usize) -> PhysicalPlanRef {
