@@ -35,3 +35,15 @@ def test_list_bool_and(table):
 def test_list_bool_or(table):
     result = table.eval_expression_list([col("a").list.bool_or()])
     assert result.to_pydict() == {"a": [True, True, False, True, False, None, None]}
+
+
+@pytest.mark.parametrize("table", [table, fixed_table])
+def test_list_bool_max(table):
+    result = table.eval_expression_list([col("a").list.max()])
+    assert result.to_pydict() == {"a": [True, True, False, True, False, None, None]}
+
+
+@pytest.mark.parametrize("table", [table, fixed_table])
+def test_list_bool_min(table):
+    result = table.eval_expression_list([col("a").list.min()])
+    assert result.to_pydict() == {"a": [True, False, False, True, False, None, None]}
