@@ -10,12 +10,10 @@ import daft
 from daft import Window, col
 from daft.expressions import interval
 from daft.functions import dense_rank, rank, row_number
-from daft.sql.sql import SQLCatalog
 from tests.conftest import assert_df_equals, get_tests_daft_runner_name
 
 pytestmark = pytest.mark.skipif(
     get_tests_daft_runner_name() == "ray",
-    # and get_context().daft_execution_config.use_experimental_distributed_engine is False,
     reason="requires Native Runner to be in use",
 )
 
@@ -35,7 +33,7 @@ def test_row_number_window_function():
 
     df = daft.from_pydict(data)
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -49,7 +47,7 @@ def test_row_number_window_function():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -68,7 +66,7 @@ def test_rank_window_function():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -82,7 +80,7 @@ def test_rank_window_function():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -101,7 +99,7 @@ def test_dense_rank_window_function():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -115,7 +113,7 @@ def test_dense_rank_window_function():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -134,7 +132,7 @@ def test_lag_with_one_arg():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -148,7 +146,7 @@ def test_lag_with_one_arg():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -167,7 +165,7 @@ def test_lag_with_two_args():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -181,7 +179,7 @@ def test_lag_with_two_args():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -200,7 +198,7 @@ def test_lag_with_three_args():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -214,7 +212,7 @@ def test_lag_with_three_args():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -235,7 +233,7 @@ def test_lead_with_one_arg():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -249,7 +247,7 @@ def test_lead_with_one_arg():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -270,7 +268,7 @@ def test_lead_with_two_args():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -284,7 +282,7 @@ def test_lead_with_two_args():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -305,7 +303,7 @@ def test_lead_with_three_args():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -319,7 +317,7 @@ def test_lead_with_three_args():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -340,7 +338,7 @@ def test_multiple_window_functions():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -355,7 +353,7 @@ def test_multiple_window_functions():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -388,7 +386,7 @@ def test_row_number_and_running_sum_window_functions():
 
     df = daft.from_pydict(data)
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -407,7 +405,7 @@ def test_row_number_and_running_sum_window_functions():
         FROM test_data
         ORDER BY category, value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("value")
@@ -444,7 +442,7 @@ def test_range_window_sql():
 
     df = daft.from_pydict(data)
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -475,7 +473,7 @@ def test_range_window_sql():
         FROM test_data
         ORDER BY category, ts
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("ts", desc=False).range_between(-2, 2)
@@ -489,7 +487,12 @@ def test_range_window_sql():
         .collect()
     )
 
-    assert_df_equals(sql_result.to_pandas(), daft_result.to_pandas(), sort_key=["category", "ts"], check_dtype=False)
+    assert_df_equals(
+        sql_result.to_pandas(),
+        daft_result.to_pandas(),
+        sort_key=["category", "ts"],
+        check_dtype=False,
+    )
 
 
 def test_range_window_desc_sql():
@@ -511,7 +514,7 @@ def test_range_window_desc_sql():
 
     df = daft.from_pydict(data)
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -542,7 +545,7 @@ def test_range_window_desc_sql():
         FROM test_data
         ORDER BY category, ts
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("ts", desc=True).range_between(-2, 2)
@@ -556,7 +559,12 @@ def test_range_window_desc_sql():
         .collect()
     )
 
-    assert_df_equals(sql_result.to_pandas(), daft_result.to_pandas(), sort_key=["category", "ts"], check_dtype=False)
+    assert_df_equals(
+        sql_result.to_pandas(),
+        daft_result.to_pandas(),
+        sort_key=["category", "ts"],
+        check_dtype=False,
+    )
 
 
 def test_range_window_with_dates():
@@ -579,7 +587,7 @@ def test_range_window_with_dates():
     pdf = pd.DataFrame(data)
     df = daft.from_pandas(pdf)
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -600,7 +608,7 @@ def test_range_window_with_dates():
         FROM test_data
         ORDER BY category, date
         """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().partition_by("category").order_by("date").range_between(interval(days=-3), interval(days=3))
@@ -613,7 +621,10 @@ def test_range_window_with_dates():
     )
 
     assert_df_equals(
-        sql_result.to_pandas(), daft_result.to_pandas(), sort_key=["category", "date", "value"], check_dtype=False
+        sql_result.to_pandas(),
+        daft_result.to_pandas(),
+        sort_key=["category", "date", "value"],
+        check_dtype=False,
     )
 
 
@@ -625,7 +636,7 @@ def test_order_by_only_row_number():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -637,7 +648,7 @@ def test_order_by_only_row_number():
         FROM test_data
         ORDER BY value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by("value")
@@ -655,7 +666,7 @@ def test_order_by_only_rank():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -667,7 +678,7 @@ def test_order_by_only_rank():
         FROM test_data
         ORDER BY value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by("value")
@@ -685,7 +696,7 @@ def test_order_by_only_dense_rank():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -697,7 +708,7 @@ def test_order_by_only_dense_rank():
         FROM test_data
         ORDER BY value
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by("value")
@@ -715,7 +726,7 @@ def test_order_by_only_desc():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -727,7 +738,7 @@ def test_order_by_only_desc():
         FROM test_data
         ORDER BY value DESC
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by("value", desc=True)
@@ -761,7 +772,7 @@ def test_order_by_nulls(desc, nulls_first):
         "value": values,
     }
     df = daft.from_pydict(data)
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
     desc_str = "DESC" if desc else "ASC"
     nulls_first_str = "NULLS FIRST" if nulls_first else "NULLS LAST"
     sql_result = daft.sql(
@@ -775,7 +786,7 @@ def test_order_by_nulls(desc, nulls_first):
         FROM test_data
         ORDER BY id
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by("value", desc=desc, nulls_first=nulls_first)
@@ -800,7 +811,7 @@ def test_order_by_only_multiple_columns():
         }
     )
 
-    catalog = SQLCatalog({"test_data": df})
+    bindings = {"test_data": df}
 
     sql_result = daft.sql(
         """
@@ -813,7 +824,7 @@ def test_order_by_only_multiple_columns():
         FROM test_data
         ORDER BY x, y
     """,
-        catalog=catalog,
+        **bindings,
     ).collect()
 
     window_spec = Window().order_by(["x", "y"])
